@@ -4,13 +4,9 @@ import inspect
 import sys
 from os import path
 
-from typing import TYPE_CHECKING
-if TYPE_CHECKING:
-    from types import ModuleType
-
 
 def linkcode_helper(domain, info,
-                    package: 'ModuleType',
+                    prefix: str,
                     github_url: str,
                     github_version: str = 'master'):
     # Resolve function for the linkcode extension.
@@ -31,8 +27,7 @@ def linkcode_helper(domain, info,
         fn = None
     if not fn:
         return None
-    fn = path.relpath(fn, start=path.dirname(
-        path.dirname(package.__file__)))
+    fn = path.relpath(fn, start=prefix)
     try:
         source, lineno = inspect.getsourcelines(obj)
         fn += f'#L{lineno}-L{lineno + len(source) - 1}'
